rain and wavesurge: Rain and wavesurge datasets.
Description
Rainfall and wave-surge data sets.Usage
data(rain)
data(wavesurge)
format
The format of the rain data is:
num [1:17531] 0 2.3 1.3 6.9 4.6 0 1 1.5 1.8 1.8 ... The wave-surge data is biviate and is used for testing
functions in texmex.
source
Copied from the ismev package.Details
The datasets are used by Coles and appear in the ismev package.References
S. Coles, An Introduction to Statistical Modeling of Extreme Values, Springer, 2001